==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/auditmanager/kotlin/AccountRegistrationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.auditmanager.kotlin

import com.pulumi.aws.auditmanager.AccountRegistrationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Resource for managing AWS Audit Manager Account Registration.
 * ## Example Usage
 * ### Basic Usage
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.auditmanager.AccountRegistration;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var example = new AccountRegistration("example");
 *     }
 * }
 * ```
 * ### Deregister On Destroy
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.auditmanager.AccountRegistration;
 * import com.pulumi.aws.auditmanager.AccountRegistrationArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var example = new AccountRegistration("example", AccountRegistrationArgs.builder()
 *             .deregisterOnDestroy(true)
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * Using `pulumi import`, import Audit Manager Account Registration resources using the `id`. For example:
 * ```sh
 *  $ pulumi import aws:auditmanager/accountRegistration:AccountRegistration example us-east-1
 * ```
 * @property delegatedAdminAccount Identifier for the delegated administrator account.
 * @property deregisterOnDestroy Flag to deregister AuditManager in the account upon destruction. Defaults to `false` (ie. AuditManager will remain active in the account, even if this resource is removed).
 * @property kmsKey KMS key identifier.
 */
public data class AccountRegistrationArgs(
    public val delegatedAdminAccount: Output<String>? = null,
    public val deregisterOnDestroy: Output<Boolean>? = null,
    public val kmsKey: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.auditmanager.AccountRegistrationArgs> {
    override fun toJava(): com.pulumi.aws.auditmanager.AccountRegistrationArgs =
        com.pulumi.aws.auditmanager.AccountRegistrationArgs.builder()
            .delegatedAdminAccount(delegatedAdminAccount?.applyValue({ args0 -> args0 }))
            .deregisterOnDestroy(deregisterOnDestroy?.applyValue({ args0 -> args0 }))
            .kmsKey(kmsKey?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AccountRegistrationArgs].
 */
@PulumiTagMarker
public class AccountRegistrationArgsBuilder internal constructor() {
    private var delegatedAdminAccount: Output<String>? = null

    private var deregisterOnDestroy: Output<Boolean>? = null

    private var kmsKey: Output<String>? = null

    /**
     * @param value Identifier for the delegated administrator account.
     */
    @JvmName("cpfppntjxqfbqvhn")
    public suspend fun delegatedAdminAccount(`value`: Output<String>) {
        this.delegatedAdminAccount = value
    }

    /**
     * @param value Flag to deregister AuditManager in the account upon destruction. Defaults to `false` (ie. AuditManager will remain active in the account, even if this resource is removed).
     */
    @JvmName("xnaapsgwhlypkivc")
    public suspend fun deregisterOnDestroy(`value`: Output<Boolean>) {
        this.deregisterOnDestroy = value
    }

    /**
     * @param value KMS key identifier.
     */
    @JvmName("mbvvqjnrivbktnpy")
    public suspend fun kmsKey(`value`: Output<String>) {
        this.kmsKey = value
    }

    /**
     * @param value Identifier for the delegated administrator account.
     */
    @JvmName("xjpndjndhqgyycoa")
    public suspend fun delegatedAdminAccount(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.delegatedAdminAccount = mapped
    }

    /**
     * @param value Flag to deregister AuditManager in the account upon destruction. Defaults to `false` (ie. AuditManager will remain active in the account, even if this resource is removed).
     */
    @JvmName("rcclyudeaiegiylk")
    public suspend fun deregisterOnDestroy(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deregisterOnDestroy = mapped
    }

    /**
     * @param value KMS key identifier.
     */
    @JvmName("fmnfgxwknhuwvqpc")
    public suspend fun kmsKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kmsKey = mapped
    }

    internal fun build(): AccountRegistrationArgs = AccountRegistrationArgs(
        delegatedAdminAccount = delegatedAdminAccount,
        deregisterOnDestroy = deregisterOnDestroy,
        kmsKey = kmsKey,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/auditmanager/kotlin/AccountRegistrationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.auditmanager.kotlin

import com.pulumi.aws.auditmanager.AccountRegistrationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Resource for managing AWS Audit Manager Account Registration.
 * ## Example Usage
 * ### Basic Usage
 * <!--Start PulumiCodeChooser -->
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 * const example = new aws.auditmanager.AccountRegistration("example", {});
 * ```
 * ```python
 * import pulumi
 * import pulumi_aws as aws
 * example = aws.auditmanager.AccountRegistration("example")
 * ```
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using Aws = Pulumi.Aws;
 * return await Deployment.RunAsync(() =>
 * {
 *     var example = new Aws.Auditmanager.AccountRegistration("example");
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-aws/sdk/v6/go/aws/auditmanager"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := auditmanager.NewAccountRegistration(ctx, "example", nil)
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.auditmanager.AccountRegistration;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var example = new AccountRegistration("example");
 *     }
 * }
 * ```
 * ```yaml
 * resources:
 *   example:
 *     type: aws:auditmanager:AccountRegistration
 * ```
 * <!--End PulumiCodeChooser -->
 * ### Deregister On Destroy
 * <!--Start PulumiCodeChooser -->
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 * const example = new aws.auditmanager.AccountRegistration("example", {deregisterOnDestroy: true});
 * ```
 * ```python
 * import pulumi
 * import pulumi_aws as aws
 * example = aws.auditmanager.AccountRegistration("example", deregister_on_destroy=True)
 * ```
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using Aws = Pulumi.Aws;
 * return await Deployment.RunAsync(() =>
 * {
 *     var example = new Aws.Auditmanager.AccountRegistration("example", new()
 *     {
 *         DeregisterOnDestroy = true,
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-aws/sdk/v6/go/aws/auditmanager"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := auditmanager.NewAccountRegistration(ctx, "example", &auditmanager.AccountRegistrationArgs{
 * 			DeregisterOnDestroy: pulumi.Bool(true),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.auditmanager.AccountRegistration;
 * import com.pulumi.aws.auditmanager.AccountRegistrationArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var example = new AccountRegistration("example", AccountRegistrationArgs.builder()
 *             .deregisterOnDestroy(true)
 *             .build());
 *     }
 * }
 * ```
 * ```yaml
 * resources:
 *   example:
 *     type: aws:auditmanager:AccountRegistration
 *     properties:
 *       deregisterOnDestroy: true
 * ```
 * <!--End PulumiCodeChooser -->
 * ## Import
 * Using `pulumi import`, import Audit Manager Account Registration resources using the `id`. For example:
 * ```sh
 * $ pulumi import aws:auditmanager/accountRegistration:AccountRegistration example us-east-1
 * ```
 * @property delegatedAdminAccount Identifier for the delegated administrator account.
 * @property deregisterOnDestroy Flag to deregister AuditManager in the account upon destruction. Defaults to `false` (ie. AuditManager will remain active in the account, even if this resource is removed).
 * @property kmsKey KMS key identifier.
 */
public data class AccountRegistrationArgs(
    public val delegatedAdminAccount: Output<String>? = null,
    public val deregisterOnDestroy: Output<Boolean>? = null,
    public val kmsKey: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.auditmanager.AccountRegistrationArgs> {
    override fun toJava(): com.pulumi.aws.auditmanager.AccountRegistrationArgs =
        com.pulumi.aws.auditmanager.AccountRegistrationArgs.builder()
            .delegatedAdminAccount(delegatedAdminAccount?.applyValue({ args0 -> args0 }))
            .deregisterOnDestroy(deregisterOnDestroy?.applyValue({ args0 -> args0 }))
            .kmsKey(kmsKey?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AccountRegistrationArgs].
 */
@PulumiTagMarker
public class AccountRegistrationArgsBuilder internal constructor() {
    private var delegatedAdminAccount: Output<String>? = null

    private var deregisterOnDestroy: Output<Boolean>? = null

    private var kmsKey: Output<String>? = null

    /**
     * @param value Identifier for the delegated administrator account.
     */
    @JvmName("jlydtnkxnejfygqn")
    public suspend fun delegatedAdminAccount(`value`: Output<String>) {
        this.delegatedAdminAccount = value
    }

    /**
     * @param value Flag to deregister AuditManager in the account upon destruction. Defaults to `false` (ie. AuditManager will remain active in the account, even if this resource is removed).
     */
    @JvmName("deutsduogajnowaw")
    public suspend fun deregisterOnDestroy(`value`: Output<Boolean>) {
        this.deregisterOnDestroy = value
    }

    /**
     * @param value KMS key identifier.
     */
    @JvmName("backwcpywrqybfpk")
    public suspend fun kmsKey(`value`: Output<String>) {
        this.kmsKey = value
    }

    /**
     * @param value Identifier for the delegated administrator account.
     */
    @JvmName("vcfjbrymvlmjrqcb")
    public suspend fun delegatedAdminAccount(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.delegatedAdminAccount = mapped
    }

    /**
     * @param value Flag to deregister AuditManager in the account upon destruction. Defaults to `false` (ie. AuditManager will remain active in the account, even if this resource is removed).
     */
    @JvmName("omicphgswntojvey")
    public suspend fun deregisterOnDestroy(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deregisterOnDestroy = mapped
    }

    /**
     * @param value KMS key identifier.
     */
    @JvmName("rdlpjowtsdibvwcp")
    public suspend fun kmsKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kmsKey = mapped
    }

    internal fun build(): AccountRegistrationArgs = AccountRegistrationArgs(
        delegatedAdminAccount = delegatedAdminAccount,
        deregisterOnDestroy = deregisterOnDestroy,
        kmsKey = kmsKey,
    )
}
